@@ -6,7 +6,7 @@
 
 MAJOR <- "0"
 MINOR <- "8"
-REVISION <- unlist(strsplit("$Revision: 57 $", split=" "))[2]
+REVISION <- unlist(strsplit("$Revision: 62 $", split=" "))[2]
 VERSION <- paste(MAJOR, MINOR, REVISION, sep=".")
 COPYRIGHT <- paste("(c) 2007 Felix Andrews <felix@nfrac.org>\n",
 	" based on Rattle (c) 2006 Graham.Williams@togaware.com")
@@ -42,7 +42,7 @@ SITELIST.FORMATS <- list(
 )
 
 CATCHMENT.FORMATS <- list(
-	"ESRI shapefile"='read.catchment.esri_shapefile'
+	"ESRI shapefile"='readShapePoly'
 )
 
 # this stores application (non-project) state information
@@ -74,6 +74,9 @@ hydrosanity <- function() {
 	gladeXMLSignalAutoconnect(StateEnv$GUI)
 	gSignalConnect(StateEnv$win, "delete-event", .hs_on_menu_quit_activate)
 	
+	freezeGUI()
+	on.exit(thawGUI())
+	
 	# set up log page
 	addInitialLogMessage()
 	
@@ -146,6 +149,7 @@ hydrosanity <- function() {
 	theWidget("corr_relationplot_aggr2_comboboxentry")$setActive(4)
 	
 	setTextviewMonospace(theWidget("log_textview"))
+	setTextviewMonospace(theWidget("core_log_textview"))
 	setTextviewMonospace(theWidget("impute_textview"))
 	setTextviewMonospace(theWidget("corr_contiguous_textview"))
 	
@@ -278,14 +282,14 @@ regionModificationUpdate <- function() {
 }
 
 .hs_on_notebook_switch_page <- function(widget, page, page.num, ...) {
-	StateEnv$win$setSensitive(F)
-	on.exit(StateEnv$win$setSensitive(T))
-	setStatusBar("")
+	freezeGUI()
+	on.exit(thawGUI())
 	
 	updateNow(page.num=page.num)
 }
 
 .hs_on_menu_quit_activate <- function(action, window) {
+	freezeGUI()
 	if (exists("hsp") && hsp$modified && (length(hsp$data) > 0)) {
 		if (!is.null(questionDialog("Save project?"))) {
 			saveProject()
@@ -299,7 +303,6 @@ regionModificationUpdate <- function() {
 }
 
 .hs_on_menu_about_activate <-  function(action, window) {
-	setStatusBar("")
 	about <- gladeXMLNew(getpackagefile("hydrosanity.glade"), 
 		root="aboutdialog")
 	about$getWidget("aboutdialog")$setVersion(VERSION)
@@ -308,22 +311,25 @@ regionModificationUpdate <- function() {
 }
 
 .hs_on_export_log_button_clicked <- function(button) {
-	StateEnv$win$setSensitive(F)
-	on.exit(StateEnv$win$setSensitive(T))
-	setStatusBar("")
+	freezeGUI()
+	on.exit(thawGUI())
 	
-	filename <- choose.file.save("log.R", caption="Export Log", 
-		filters=Filters[c("R","txt","All"),])
+	which_log <- if (theWidget("log_notebook")$getCurrentPage() == 0)
+		"log" else "core_log"
+	
+	filename <- choose.file.save(paste(which_log, "R", sep="."), 
+		caption="Export Log", filters=Filters[c("R","txt","All"),])
 	StateEnv$win$present()
-	if (is.na(filename)) { return() }
+	if (is.na(filename)) return()
 	
 	if (get.extension(filename) == "") {
-		filename <- sprintf("%s.R", filename)
+		filename <- paste(filename, "R", sep=".")
 	}
 	
-	write(getTextviewText(theWidget("log_textview")), filename)
+	which_widget <- theWidget(paste(which_log, "_textview", sep=""))
+	write(getTextviewText(which_widget), filename)
 	
-	setStatusBar("The log has been exported to ", filename)
+	setStatusBar("The ", which_log, " has been exported to ", filename)
 }
 
 
@@ -370,18 +376,12 @@ sanitycheck.flow <- function(timeblobList) {
 getpackagefile <- function(filename) {
 	## Try firstly to load from the installed hydrosanity package
 	## Otherwise, look locally.
-	myPath <- ""
-	result <- try(etc <- file.path(.path.package(package="hydrosanity")[1], "etc"), silent=TRUE)
-	if (inherits(result, "try-error")) {
-		myPath <- file.path("hydrosanity", "hydrosanity", "inst", "etc", filename)
-	} else {
-		myPath <- file.path(etc, filename)
-	}
-	if (!file.exists(myPath)) {
-		stop("could not find file ", filename)
-	} else {
-		return(myPath)
-	}
+	myPath <- system.file("etc", filename, package = "hydrosanity")
+	if (identical(myPath, "")) 
+		myPath <- file.path("hydrosanity", "hydrosanity", "inst", 
+			"etc", filename)
+	if (!file.exists(myPath)) stop("could not find file ", filename)
+	myPath
 }
 
 
@@ -463,11 +463,3 @@ select.sites.BOM.AU <- function(siteListFile, archivePath, return.data=FALSE, xl
 	return(dataset)
 }
 
-read.catchment.esri_shapefile <- function(file) {
-	stopifnot(require(maptools))
-	theShape <- read.shape(file)
-	# assuming: Shapefile type: Polygon, (5), # of Shapes: 1
-	return(theShape$Shapes[[1]]$verts)
-}
-
-
