@@ -20,9 +20,8 @@ updateMultivarPage <- function() {
 }
 
 .hs_on_multivar_relationplot_button_clicked <- function(button) {
-	StateEnv$win$setSensitive(F)
-	on.exit(StateEnv$win$setSensitive(T))
-	setStatusBar("")
+	freezeGUI(use.core.log=F)
+	on.exit(thawGUI())
 	
 	selNames <- iconViewGetSelectedNames(theWidget("selection_iconview"))
 	if (length(selNames) == 0) {
@@ -62,7 +61,7 @@ updateMultivarPage <- function() {
 	if (doAggr1 || doAggr2) {
 		aggrBy <- if (doAggr1) { aggr1By } else { aggr2By }
 		aggr.call <- bquote(
-			tmp.data <- lapply(tmp.data, aggregate.timeblob, by=.(aggrBy))
+			tmp.data <- lapply(tmp.data, aggregate.timeblob, by=.(aggrBy), fun.qual="omit")
 		)
 		if (any(grep("( month|year)", aggrBy))) {
 			aggr.call[[3]]$start.month <- hsp$startMonth
@@ -114,9 +113,8 @@ updateMultivarPage <- function() {
 }
 
 .hs_on_multivar_lagseries_button_clicked <- function(button) {
-	StateEnv$win$setSensitive(F)
-	on.exit(StateEnv$win$setSensitive(T))
-	setStatusBar("")
+	freezeGUI(use.core.log=F)
+	on.exit(thawGUI())
 	
 	selNames <- iconViewGetSelectedNames(theWidget("selection_iconview"))
 	if (length(selNames) == 0) {
@@ -150,7 +148,7 @@ updateMultivarPage <- function() {
 	))
 	for (i in seq_along(tmp.chunks)[-1]) {
 		guiDo(call=bquote({
-			tmp.win <- findIntervalPeriod(.(tmp.chunks[i-1]), 
+			tmp.win <- findIntervalRange(.(tmp.chunks[i-1]), 
 				.(tmp.chunks[i]), tmp.data$Time)
 			tmp.win <- seq(tmp.win[1], tmp.win[2])
 			tmp.ts <- try(na.contiguous(ts.intersect(as.ts(tmp.data[tmp.win,2]), 
