@@ -3,6 +3,7 @@
 ## Copyright (c) 2007 Felix Andrews <felix@nfrac.org>, GPL
 
 
+
 grid.timeline.plot <- function(blob.list, xscale=NULL, colMap=NULL, barThickness=unit(1.2,"lines"), auto.key=T, maxLabelChars=20, pad=unit(1,"lines"), grill=T, main=NULL, sub=T, newpage=T) {
 	# check types
 	if (!identical(class(blob.list),"list")) { blob.list <- list(blob.list) }
@@ -761,185 +762,6 @@ grid.xaxis.POSIXt <- function(lim=as.numeric(convertX(unit(c(0,1), "npc"), "nati
 	tmp
 }
 
-
-# this panel function may be used in either xyplot or levelplot
-panel.geo <- function(x, y, z=NULL, z.interp, subscripts, 
-	layers=c("labels", "points", "surface", "catchment", "cities", "rivers", "countries"), 
-	points.xy=NULL, pch=19, points.labels, catchment.poly, contour=F, region=T, at, col.contours=grey(0.5), 
-	gp.labels=gpar(cex=0.7), gp.catchment=gpar(col="black"), gp.countries=gpar(col="black"), gp.cities=gpar(col="black", cex=0.7), pch.cities=15,
-	gp.rivers=gpar(col="blue", lty="longdash"), 
-	xo.length=64, yo.length=xo.length, linear=T, extrap=F, ...) {
-	
-	xlim <- convertX(unit(0:1,"npc"), "native", valueOnly=T)
-	ylim <- convertY(unit(0:1,"npc"), "native", valueOnly=T)
-	
-	# draw interpolated surface
-	if ("surface" %in% layers) {
-		if (!missing(z.interp) && require(akima)) {
-			z <- z.interp
-			# x y z.interp need to be interpolated
-			# (this is probably xyplot, not levelplot)
-			# only interpolate with sites in twice visible range
-			xlim.use <- xlim + diff(xlim) * c(-0.5, 0.5)
-			ylim.use <- ylim + diff(ylim) * c(-0.5, 0.5)
-			# find subset of points to use
-			ok <- ((min(xlim.use) < x) & (x < max(xlim.use)) &
-				(min(ylim.use) < y) & (y < max(ylim.use)))
-			ok <- ok & (subscripts %in% seq_along(x))
-			ok <- ok & complete.cases(x, y, z)
-			if (sum(ok) < 4) {
-				warning("at least 4 locations are required for interpolation")
-				z <- NULL
-			} else {
-				# construct marginal dimensions of grid
-				xo <- seq(min(xlim), max(xlim), length=xo.length)
-				yo <- seq(min(ylim), max(ylim), length=yo.length)
-				tmp.grid <- expand.grid(x=xo, y=yo)
-				# compute the spatial field (interpolation)
-				tmp.grid$z <- as.vector(
-					interp(x=x[ok], y=y[ok], z=z[ok], 
-					xo=xo, yo=yo, linear=linear, 
-					extrap=extrap, duplicate="mean")$z)
-				# restrict surface within observed limits (for spline silliness)
-				if (!linear) {
-					tmp.grid$z <- pmax(min(z[ok]), pmin(max(z[ok]), tmp.grid$z))
-				}
-				if (missing(points.xy)) {
-					points.xy <- list(x=x, y=y)
-				}
-				x <- tmp.grid$x
-				y <- tmp.grid$y
-				z <- tmp.grid$z
-			}
-		}
-		if (!is.null(z)) {
-			# x y z on a grid (levelplot)
-			
-			myAt <- if (contour) pretty(z) else
-				seq(min(z, na.rm=T), max(z, na.rm=T), length=100)
-			if (!missing(at)) { myAt <- at }
-			mySubscripts <- if (missing(z.interp)) subscripts else T
-			panel.levelplot(x, y, z, subscripts=mySubscripts, contour=contour,
-				region=region, at=myAt,
-				col=col.contours, labels=list(col=col.contours), ...)
-		}
-	}
-	# draw map lines for national boundaries
-	if ("countries" %in% layers) {
-		if (require(mapdata, quietly=T)) {
-			try({
-				mapdb <- map("worldHires", plot=F, xlim=xlim, ylim=ylim)
-				grid.lines(mapdb$x, mapdb$y, gp=gp.countries, 
-					default.units="native")
-			}, silent=T)
-		} else
-		# Australia: 'oz' package has better resolution than 'maps'
-	# commented out to pass R CMD check
-	#	if ((113 <= max(xlim)) && (min(xlim) <= 154) && 
-	#		(-44 <= max(ylim)) && (min(ylim) <= -10) &&
-	#		require(oz, quietly=T)) {
-	#		for (i in ozRegion(xlim=xlim, ylim=ylim)$lines) {
-	#			grid.lines(i$x, i$y, gp=gp.countries, 
-	#				default.units="native")
-	#		}
-	#	} else
-		if (require(maps)) {
-			try({
-				mapdb <- map("world", plot=F, xlim=xlim, ylim=ylim)
-				grid.lines(mapdb$x, mapdb$y, gp=gp.countries, 
-					default.units="native")
-			}, silent=T)
-		}
-	}
-	# draw rivers
-	if ("rivers" %in% layers) {
-		if (require(maps, quietly=T)) {
-			try({
-				mapdb <- map("rivers", plot=F, xlim=xlim, ylim=ylim)
-				grid.lines(mapdb$x, mapdb$y, gp=gp.rivers,
-					default.units="native")
-			}, silent=T)
-		}
-	}
-	# draw cities
-	if (("cities" %in% layers) && require(maps)) {
-		data(world.cities)
-		with(world.cities, {
-			ok <- ((min(xlim) < long) & (long < max(xlim)) &
-				(min(ylim) < lat) & (lat < max(ylim)))
-			if (any(ok)) {
-				ux <- unit(long[ok], "native")
-				uy <- unit(lat[ok], "native")
-				grid.points(ux, uy, gp=gp.cities, pch=pch.cities)
-				grid.text(ux, uy - unit(0.5, "char"), just="top",
-					label=name[ok], check.overlap=T, gp=gp.cities)
-			}
-		})
-	}
-	# draw catchment
-	if (("catchment" %in% layers) && !missing(catchment.poly)) {
-		grid.polygon(catchment.poly[,1], catchment.poly[,2], 
-			gp=gp.catchment, default.units="native")
-	}
-	# draw data points
-	if (any(c("points", "labels") %in% layers)) {
-		if (("surface" %in% layers) && missing(z.interp) && !is.null(z) && missing(points.xy)) {
-			# x and y are a grid of points (for levelplot)
-			# and points.xy not given; so don't have points
-			return()
-		}
-		if (!is.null(points.xy)) {
-			myX <- points.xy$x
-			myY <- points.xy$y
-		} else {
-			myX <- x
-			myY <- y
-		}
-		if (length(myX) > length(subscripts)) {
-			myX <- myX[subscripts]
-			myY <- myY[subscripts]
-		}
-		ux <- unit(myX, "native")
-		uy <- unit(myY, "native")
-		if ("points" %in% layers) {
-			#panel.xyplot(myX, myY, ...)
-			panel.points(myX, myY, pch=pch)
-		}
-		if (("labels" %in% layers) && !missing(points.labels)) {
-			if (length(points.labels) > length(subscripts)) {
-				points.labels <- points.labels[subscripts]
-			}
-			myJust <- "centre"
-			if ("points" %in% layers) {
-				uy <- uy - unit(0.5, "char")
-				myJust <- "top"
-			}
-			grid.text(ux, uy, label=points.labels, just=myJust, 
-				gp=gp.labels)
-		}
-	}
-}
-
-panel.interp <- function(x, y, z, ...) {
-	panel.geo(x, y, z.interp, ..., layers=c("surface"))
-}
-
-panel.map <- function(...) {
-	panel.geo(..., layers=c("countries", "cities", "rivers"))
-}
-
-# extend default limits by 10% on each side
-prepanel.extend.10 <- function(...) {
-	tmp <- lattice:::prepanel.default.xyplot(...)
-	if (is.numeric(tmp$xlim)) {
-		tmp$xlim <- extendrange(r=tmp$xlim, f=0.1)
-	}
-	if (is.numeric(tmp$ylim)) {
-		tmp$ylim <- extendrange(r=tmp$ylim, f=0.1)
-	}
-	tmp
-}
-
 # prepanel.default.qqmath fails to take range(x, finite=T)
 prepanel.qqmath.fix <- function(x, ...) {
 	tmp <- lattice:::prepanel.default.qqmath(x, ...)
